import 'dart:convert';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'AppTranslations.dart';

class Translations {
  final Locale locale;
  Translations(this.locale);
  static Translations of(BuildContext context) =>
      Localizations.of<Translations>(context, Translations);

  static const LocalizationsDelegate<Translations> delegate =
      _LocalizationsDelegate();

  Map<String, String> _localizedStrings;

  Future<bool> load() async {
    String jsonString = await rootBundle.loadString(
        '${AppTranslations().assetLang}${locale.languageCode}.json');
    Map<String, dynamic> jsonMap = json.decode(jsonString);

    _localizedStrings = jsonMap.map((key, value) {
      return MapEntry(key, value.toString());
    });
    return true;
  }

  String translate(String key) {
    return _localizedStrings[key] ?? "$key not found";
  }
}

class _LocalizationsDelegate extends LocalizationsDelegate<Translations> {
  const _LocalizationsDelegate();

  @override
  bool isSupported(Locale locale) {
    return AppTranslations()
        .supportedLanguagesCodes
        .contains(locale.languageCode);
  }

  @override
  Future<Translations> load(Locale locale) async {
    Translations localizations = Translations(locale);
    await localizations.load();
    return localizations;
  }

  @override
  bool shouldReload(_LocalizationsDelegate old) => false;
}
