import 'dart:io';
import 'package:flutter/material.dart';
import 'cupertino_settings_item.dart';

enum _SettingsTileType { simple, switchTile }

// ignore: must_be_immutable
class SettingsTile extends StatelessWidget {
  final String title;
  final String subtitle;
  final Widget leading;
  final Widget trailing;
  final VoidCallback onTap;
  final Function(bool value) onToggle;
  final bool switchValue;
  final bool enabled;
  final _SettingsTileType _tileType;
  int viewStyleIos;
  SettingsTile(
      {Key key,
      @required this.title,
      this.subtitle,
      this.leading,
      this.trailing,
      this.onTap,
      this.enabled = true,
      this.viewStyleIos})
      : _tileType = _SettingsTileType.simple,
        onToggle = null,
        switchValue = null,
        super(key: key);

  SettingsTile.switchTile(
      {Key key,
      @required this.title,
      this.subtitle,
      this.leading,
      this.enabled = true,
      this.trailing,
      @required this.onToggle,
      @required this.switchValue,
      this.viewStyleIos})
      : _tileType = _SettingsTileType.switchTile,
        onTap = null,
        super(key: key);

  @override
  Widget build(BuildContext context) {
    if (this.viewStyleIos == 1)
      return iosTile();
    else if (this.viewStyleIos == 2)
      return androidTile();
    else if (Platform.isIOS)
      return iosTile();
    else
      return androidTile();
  }

  Widget iosTile() {
    if (_tileType == _SettingsTileType.switchTile) {
      return CupertinoSettingsItem(
        enabled: enabled,
        type: SettingsItemType.toggle,
        label: title,
        leading: leading,
        switchValue: switchValue,
        onToggle: onToggle,
      );
    } else {
      return CupertinoSettingsItem(
        enabled: enabled,
        type: SettingsItemType.modal,
        label: title,
        value: subtitle,
        trailing: trailing,
        hasDetails: false,
        leading: leading,
        onPress: onTap,
      );
    }
  }

  Widget androidTile() {
    if (_tileType == _SettingsTileType.switchTile) {
      return SwitchListTile(
        secondary: leading,
        value: switchValue,
        onChanged: enabled ? onToggle : null,
        title: Text(title),
        subtitle: subtitle != null ? Text(subtitle) : null,
      );
    } else {
      return ListTile(
        title: Text(title),
        subtitle: subtitle != null ? Text(subtitle) : null,
        leading: leading,
        enabled: enabled,
        trailing: trailing,
        onTap: onTap,
      );
    }
  }
}
